SWDEV-432490 - fix __HIP_NO_IMAGE_SUPPORT logic

1.Skip texture/image tests when __HIP_NO_IMAGE_SUPPORT is set to prevent inevitable silent failure
2.Simplify __HIP_NO_IMAGE_SUPPORT macros

Change-Id: I54ef12a239298c534a213edf39c05c2dad06a7f4


[ROCm/hip-tests commit: 0ee0e4ab4a]
This commit is contained in:
Todd tiantuo Li
2024-01-26 03:44:44 -08:00
committed by Rakesh Roy
parent 7df8798269
commit 14f6363879
26 changed files with 305 additions and 39 deletions
@@ -33,7 +33,7 @@ constexpr size_t ChannelToRead = 1;
template <typename T>
__global__ void readFromTexture(T* output, hipTextureObject_t texObj, size_t width, size_t height,
bool textureGather) {
#if !defined(__HIP_NO_IMAGE_SUPPORT) || !__HIP_NO_IMAGE_SUPPORT
#if !__HIP_NO_IMAGE_SUPPORT
// Calculate normalized texture coordinates
const unsigned int x = blockIdx.x * blockDim.x + threadIdx.x;
const unsigned int y = blockIdx.y * blockDim.y + threadIdx.y;
@@ -50,7 +50,7 @@ __global__ void readFromTexture(T* output, hipTextureObject_t texObj, size_t wid
output[y * width + x] = tex2D<T>(texObj, u, v);
}
}
#endif
#endif
}
template <typename T> void checkDataIsAscending(const std::vector<T>& hostData) {